@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 import argparse
-from sarscov2metaextract import convertor
-
+#from sarscov2metaextract import convertor
+from __init__ import convertor
 
 def main():
 	parser = argparse.ArgumentParser(description='Metadata extractor for SARS-CoV-2 selection analysis pipeline in Galaxy')
